@@ -6,8 +6,8 @@
 # differences.
 #
 # Copyright 2008 Insecure.Com LLC
-# Ndiff is distributed under the same license as Nmap. See the file COPYING or
-# http://nmap.org/data/COPYING. See http://nmap.org/book/man-legal.html for
+# Ndiff is distributed under the same license as Nmap. See the file LICENSE or
+# https://nmap.org/data/LICENSE. See https://nmap.org/book/man-legal.html for
 # more details.
 #
 # David Fifield
@@ -18,6 +18,11 @@ import difflib
 import getopt
 import sys
 import time
+
+# Prevent loading PyXML
+import xml
+xml.__path__ = [x for x in xml.__path__ if "_xmlplus" not in x]
+
 import xml.sax
 import xml.sax.saxutils
 import xml.dom.minidom
@@ -64,11 +69,8 @@ class Scan(object):
 
     def load_from_file(self, filename):
         """Load a scan from the Nmap XML file with the given filename."""
-        f = open(filename, "r")
-        try:
+        with open(filename, "r") as f:
             self.load(f)
-        finally:
-            f.close()
 
     def write_nmaprun_open(self, writer):
         attrs = {}
@@ -122,11 +124,12 @@ class Host(object):
     def get_id(self):
         """Return an id that is used to determine if hosts are "the same"
         across scans."""
+        hid = None
         if len(self.addresses) > 0:
-            return str(sorted(self.addresses)[0])
+            hid = "%-40s" % (str(sorted(self.addresses)[0]))
         if len(self.hostnames) > 0:
-            return str(sorted(self.hostnames)[0])
-        return id(self)
+            return (hid or " " * 40) + str(sorted(self.hostnames)[0])
+        return hid or id(self)
 
     def format_name(self):
         """Return a human-readable identifier for this host."""
@@ -321,6 +324,9 @@ class Port(object):
     def spec_string(self):
         return u"%d/%s" % self.spec
 
+    def __hash__(self):
+        return hash(self.spec)
+
     def __cmp__(self, other):
         d = cmp(self.spec, other.spec)
         if d != 0:
@@ -463,7 +469,7 @@ def format_banner(scan):
 
 
 def print_script_result_diffs_text(title, script_results_a, script_results_b,
-    script_result_diffs, f=sys.stdout):
+        script_result_diffs, f=sys.stdout):
     table = Table(u"*")
     for sr_diff in script_result_diffs:
         sr_diff.append_to_port_table(table)
@@ -479,7 +485,7 @@ def print_script_result_diffs_text(title, script_results_a, script_results_b,
 
 
 def script_result_diffs_to_dom_fragment(elem, script_results_a,
-    script_results_b, script_result_diffs, document):
+        script_results_b, script_result_diffs, document):
     if len(script_results_a) == 0 and len(script_results_b) == 0:
         return document.createDocumentFragment()
     elif len(script_results_b) == 0:
@@ -554,7 +560,6 @@ class ScanDiff(object):
             h_diff = HostDiff(host_a, host_b)
             cost += h_diff.cost
             if h_diff.cost > 0 or verbose:
-                host = host_a or host_b
                 self.output_host_diff(h_diff)
 
         post_script_result_diffs = ScriptResultDiff.diff_lists(
@@ -1184,6 +1189,7 @@ class NmapContentHandler(xml.sax.handler.ContentHandler):
     that is filled in and can be read back again once the parse method is
     finished."""
     def __init__(self, scan):
+        xml.sax.handler.ContentHandler.__init__(self)
         self.scan = scan
 
         # We keep a stack of the elements we've seen, pushing on start and
@@ -1192,23 +1198,26 @@ class NmapContentHandler(xml.sax.handler.ContentHandler):
 
         self.current_host = None
         self.current_port = None
+        self.skip_over = False
 
         self._start_elem_handlers = {
-            u"nmaprun":    self._start_nmaprun,
-            u"host":       self._start_host,
-            u"status":     self._start_status,
-            u"address":    self._start_address,
-            u"hostname":   self._start_hostname,
+            u"nmaprun": self._start_nmaprun,
+            u"host": self._start_host,
+            u"hosthint": self._start_hosthint,
+            u"status": self._start_status,
+            u"address": self._start_address,
+            u"hostname": self._start_hostname,
             u"extraports": self._start_extraports,
-            u"port":       self._start_port,
-            u"state":      self._start_state,
-            u"service":    self._start_service,
-            u"script":     self._start_script,
-            u"osmatch":    self._start_osmatch,
-            u"finished":   self._start_finished,
+            u"port": self._start_port,
+            u"state": self._start_state,
+            u"service": self._start_service,
+            u"script": self._start_script,
+            u"osmatch": self._start_osmatch,
+            u"finished": self._start_finished,
         }
         self._end_elem_handlers = {
             u'host': self._end_host,
+            u"hosthint": self._end_hosthint,
             u'port': self._end_port,
         }
 
@@ -1224,7 +1233,7 @@ class NmapContentHandler(xml.sax.handler.ContentHandler):
         done in the _start_*() handlers. This is to make it easy for them to
         bail out on error."""
         handler = self._start_elem_handlers.get(name)
-        if handler is not None:
+        if handler is not None and not self.skip_over:
             handler(name, attrs)
         self.element_stack.append(name)
 
@@ -1237,7 +1246,7 @@ class NmapContentHandler(xml.sax.handler.ContentHandler):
             handler(name)
 
     def _start_nmaprun(self, name, attrs):
-        assert self.parent_element() == None
+        assert self.parent_element() is None
         if "start" in attrs:
             start_timestamp = int(attrs.get(u"start"))
             self.scan.start_date = datetime.datetime.fromtimestamp(
@@ -1251,6 +1260,10 @@ class NmapContentHandler(xml.sax.handler.ContentHandler):
         self.current_host = Host()
         self.scan.hosts.append(self.current_host)
 
+    def _start_hosthint(self, name, attrs):
+        assert self.parent_element() == u"nmaprun"
+        self.skip_over = True
+
     def _start_status(self, name, attrs):
         assert self.parent_element() == u"host"
         assert self.current_host is not None
@@ -1407,6 +1420,9 @@ class NmapContentHandler(xml.sax.handler.ContentHandler):
         self.current_host.script_results.sort()
         self.current_host = None
 
+    def _end_hosthint(self, name):
+        self.skip_over = False
+
     def _end_port(self, name):
         self.current_port.script_results.sort()
         self.current_port = None
